pub struct Battery {Show 19 fields
pub name: Option<String>,
pub status: Option<Status>,
pub technology: Option<String>,
pub cycle_count: Option<usize>,
pub voltage_min_design: Option<f32>,
pub voltage_now: Option<f32>,
pub power_now: Option<f32>,
pub energy_full_design: Option<f32>,
pub energy_full: Option<f32>,
pub energy_now: Option<f32>,
pub capacity: Option<u8>,
pub capacity_level: Option<Level>,
pub model_name: Option<String>,
pub manufacturer: Option<String>,
pub serial_number: Option<String>,
pub charge_types: Option<String>,
pub health: Option<f32>,
pub estimated_time: Option<f32>,
pub charge_time: Option<f32>,
}Expand description
Information from the uevent file to a single battery
Fields
name: Option<String>System name of the battery device (e.g. BAT0)
status: Option<Status>The current charging status of this battery
technology: Option<String>The battery technology type
cycle_count: Option<usize>Number of charge cycles the battery has undergone
voltage_min_design: Option<f32>Minimum design voltage, V
voltage_now: Option<f32>Current voltage, V
power_now: Option<f32>Current power draw or charge rate, W
energy_full_design: Option<f32>Original design capacity, Wh
energy_full: Option<f32>Current maximum capacity the battery can hold, Wh
energy_now: Option<f32>Current remaining energy, Wh
capacity: Option<u8>Current charge level, % (0..100)
capacity_level: Option<Level>Qualitative description of the current capacity level
model_name: Option<String>The model name of the battery
manufacturer: Option<String>The manufacturer of the battery
serial_number: Option<String>The serial number of the battery
charge_types: Option<String>Supported charge types (e.g. Standard, Fast, etc.)
health: Option<f32>The estimated health of the battery, % (0..100) calculated
from energy_full / energy_full_design
estimated_time: Option<f32>Estimated time remaining until the battery is empty or full, hours
charge_time: Option<f32>Estimated time required to fully charge the battery, hours (if applicable)
Implementations