Module cpu_freq

Module cpu_freq 

Get information about CPU frequency

Example

use ferrix_lib::cpu_freq::CpuFreq;
 
let freqs = CpuFreq::new().unwrap();
dbg!(&freqs.policy);

Structs

CpuFreq
Information about power management and frequencies for the processors installed in the PC
Policy
Information about power management and the frequency of a specific core/thread