pub struct DMITable {
pub bios: Bios,
pub system: System,
pub baseboard: Baseboard,
pub chassis: Chassis,
pub processor: Processor,
pub caches: Caches,
pub ports: PortConnectors,
pub mem_array: MemoryArray,
pub mem_devices: MemoryDevices,
}Expand description
A structure containing data from the DMI table
Usage
use ferrix::dmi::DMITable;
let dmi = DMITable::new().unwrap();
dbg!(dmi);Fields
bios: BiosInformation about BIOS (Type 0)
system: SystemInformation about system (Type 1)
baseboard: BaseboardInformation about baseboard (or module) - Type 2
chassis: ChassisInformation about system enclosure or chassis - Type 3
processor: ProcessorInformation about processor - Type 4
caches: CachesInformation about CPU cache (Type 7)
ports: PortConnectorsInformation about port connectors (Type 8)
mem_array: MemoryArrayInformation about physical memory array (Type 16)
mem_devices: MemoryDevicesInformation about installed memory devices (Type 17)
Implementations
Sourceimpl DMITable
impl DMITable
Sourcepub fn new() -> Result<Self>
pub fn new() -> Result<Self>
Get information from DMI table
NOTE: This data DOES NOT NEED to be updated periodically!
Sourcepub fn to_json(&self) -> Result<String>
pub fn to_json(&self) -> Result<String>
Performs serialization of structure data in JSON.
The returned value will be a SINGLE LINE of JSON data intended for reading by third-party software or for transmission over the network.
Sourcepub fn to_json_pretty(&self) -> Result<String>
pub fn to_json_pretty(&self) -> Result<String>
Performs serialization in “pretty” JSON
JSON will contain unnecessary newline transitions and spaces to visually separate the blocks. It is well suited for human reading and analysis.