pub struct RangeLimits {
pub min_v_freq_hz: u8,
pub max_v_freq_hz: u8,
pub min_h_freq_khz: u8,
pub max_h_freq_khz: u8,
pub max_pixel_clock_mhz: u16,
}Expand description
Monitor Range Limits Descriptor (type 0xFD)
Defines the operational limits of the display to help the graphics driver select valid timing modes withoyt reading the EDID string
Fields
min_v_freq_hz: u8Minimum vertical field rate (refresh rate) in Hz
max_v_freq_hz: u8Maximum vertical field rate (refresh rate) in Hz
min_h_freq_khz: u8Minimum horizontal line rate in kHz
max_h_freq_khz: u8Maximum horizontal line rate in kHz
max_pixel_clock_mhz: u16Maximum supported pixel clock in MHz (stored as tens of MHz in EDID, multiplied
bu 10 here)
Implementations