pub struct FileSystemStats {
pub block_size: u64,
pub fragment_size: u64,
pub total_blocks: u64,
pub free_blocks: u64,
pub available_blocks: u64,
pub total_inodes: u64,
pub free_inodes: u64,
}Expand description
Filesystem usage statistics (via statvfs C function)
Fields
block_size: u64Block size, bytes
fragment_size: u64Fragment size, bytes
total_blocks: u64Total number of blocks in this fs
free_blocks: u64Total number of free blocks
available_blocks: u64Total number of free blocks available to non-privileged processes
total_inodes: u64Total number of inodes
free_inodes: u64Total number of free inodes
Implementations
Sourceimpl FileSystemStats
impl FileSystemStats
Sourcepub fn total_bytes(&self) -> u64
pub fn total_bytes(&self) -> u64
Calculate the total capacity of the fs in bytes
Sourcepub fn total_size(&self) -> Size
pub fn total_size(&self) -> Size
Calculate the total capacity of the fs as a Size enum
Sourcepub fn free_bytes(&self) -> u64
pub fn free_bytes(&self) -> u64
Calculate the free space in bytes
Sourcepub fn avail_bytes(&self) -> u64
pub fn avail_bytes(&self) -> u64
Calculate the space available to non-privileged users in bytes
pub fn avail_size(&self) -> Size
Sourcepub fn used_bytes(&self) -> u64
pub fn used_bytes(&self) -> u64
Calculate the used space in bytes
pub fn used_size(&self) -> Size
Sourcepub fn usage_percent(&self) -> f64
pub fn usage_percent(&self) -> f64
Calculate the percentage of the fs that is currently used (0.0 to 100.0)