pub struct DetailedTiming {Show 14 fields
pub pixel_clock_hz: u64,
pub h_active: u32,
pub h_blanking: u32,
pub v_active: u32,
pub v_blanking: u32,
pub h_front_porch: u32,
pub h_sync_pulse: u32,
pub v_front_porch: u32,
pub v_sync_pulse: u32,
pub h_back_porch: u32,
pub v_back_porch: u32,
pub h_sync_positive: bool,
pub v_sync_positive: bool,
pub aspect_ratio: String,
}Expand description
Single Detailed Timing Descriptor (DTD) block
A DTD contains precise timing information for a specific display mode, including active resolution, banking intervals, sync pulses, and polarity.
Fields
pixel_clock_hz: u64Pixel clock frequency in Hz
h_active: u32Active horizontal resolution in pixels
h_blanking: u32Total horizontal blanking interval in pixels
v_active: u32Active vertical resolution in lines
v_blanking: u32Total vertical blanking interval in lines
h_front_porch: u32Horizontal front porch (sync offset) in px
h_sync_pulse: u32Horizontal sync pulse width in px
v_front_porch: u32Vertical front porch (sync offset) in lines
v_sync_pulse: u32Vertical sync pulse width in lines
h_back_porch: u32Horizontal back porch in pixels
v_back_porch: u32Vertical back porch in lines
h_sync_positive: booltrue if the horizontal sync pulse is positive polarity
v_sync_positive: booltrue if the vertical sync pulse is positive polarity
aspect_ratio: StringCalculated aspect ratio for this specific timing mode
Implementations